@@ -637,14 +637,14 @@ static void parse_op(char *c, struct pci_dev **selected_devices)
       if (parse_x32(value, &f, &ll) < 0 || f && *f != ':')
 	parse_err("Invalid value \"%s\"", value);
       lim = max_values[op->width];
-      if (ll > lim && ll < ~0UL - lim)
+      if (ll > lim && ll < ~0U - lim)
 	parse_err("Value \"%s\" is out of range", value);
       op->values[j].value = ll;
       if (f && *f == ':')
 	{
 	  if (parse_x32(f+1, NULL, &ll) <= 0)
 	    parse_err("Invalid mask \"%s\"", f+1);
-	  if (ll > lim && ll < ~0UL - lim)
+	  if (ll > lim && ll < ~0U - lim)
 	    parse_err("Mask \"%s\" is out of range", f+1);
 	  op->values[j].mask = ll;
 	  op->values[j].value &= ll;
